@@ -25,13 +25,17 @@ import os
 import warnings
 from typing import TYPE_CHECKING, List, Optional, TypeVar
 
+import shut
 from .author import Author
 from .changelog import ChangelogConfiguration
 from .release import ReleaseConfiguration
 from .version import Version
+from databind.core.annotations import union
 from shut.utils.fs import get_file_in_directory
+from typing_extensions import Annotated
 
 if TYPE_CHECKING:
+  import shut.renderers
   from shut.renderers.core import Renderer
 
 T_AbstractProjectModel = TypeVar('T_AbstractProjectModel', bound='AbstractProjectModel')
@@ -47,6 +51,9 @@ class AbstractProjectModel(abc.ABC):
   url: Optional[str] = None
   changelog: ChangelogConfiguration = field(default_factory=ChangelogConfiguration)
   release: ReleaseConfiguration = field(default_factory=ReleaseConfiguration)
+  templates: List[Annotated[
+    'shut.renderers.Renderer',
+    union(union.Subtypes.entrypoint('shut.templates'), style=union.Style.flat)]] = field(default_factory=list)
 
   def __post_init__(self) -> None:
     # May be filled during the deserialization process to track additional metadata.
@@ -114,6 +121,7 @@ class AbstractProjectModel(abc.ABC):
       case_sensitive=False)
 
   def get_auxiliary_renderers(self: T_AbstractProjectModel) -> List['Renderer[T_AbstractProjectModel]']:
-    return []
+    return list(self.templates)
+
 
 from . import Project  # pylint: disable=unused-import
